summary.naive: Summary Naive
Description
Function to obtain the naive subgroup treatment effects of an object fitted
with the naive function.
Usage
# S3 method for naive
summary(object, conf = 0.95, ...)
Value
Object of class summary.elastic_net which is a list with a
data.frame with 4 columns (the subgroup variables, the estimated
treatment effect and the low and high bounds of the confidence interval of the
treatment effect), the resptype and the confidence level.
Arguments
- object
(naive)
the naive object.
- conf
(scalar)
the confidence level of the intervals. Default is
0.95.
- ...
Arguments of summary.